summaryrefslogtreecommitdiff
path: root/buildscripts/packager-enterprise.py
diff options
context:
space:
mode:
authorJohn Chen <john.chen@mongodb.com>2019-12-02 17:08:44 +0000
committerevergreen <evergreen@mongodb.com>2019-12-02 17:08:44 +0000
commit76dc06194037bee31b6eedb168f553be354b1a3c (patch)
tree257a2c3cbd20dd62c6f9d6d9acda31741109f708 /buildscripts/packager-enterprise.py
parent06c8454002da4ca1abc312755b5a3946a75b4e13 (diff)
downloadmongo-76dc06194037bee31b6eedb168f553be354b1a3c.tar.gz
SERVER-37772 adding RHEL80 distro
(cherry picked from commit 284630e3704be4be091154c5b7fe63c335e9d70c) (cherry picked from commit 8ce96274a25466e71d4ddc8fb3f92658a4b353b4)
Diffstat (limited to 'buildscripts/packager-enterprise.py')
-rwxr-xr-xbuildscripts/packager-enterprise.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/buildscripts/packager-enterprise.py b/buildscripts/packager-enterprise.py
index 50d54f83489..58862bc350f 100755
--- a/buildscripts/packager-enterprise.py
+++ b/buildscripts/packager-enterprise.py
@@ -106,7 +106,7 @@ class EnterpriseDistro(packager.Distro):
raise Exception("BUG: unsupported platform?")
def build_os(self, arch):
"""Return the build os label in the binary package to download ("rhel57", "rhel62", "rhel67" and "rhel70"
for redhat, the others are delegated to the super class
"""
if arch == "ppc64le":
@@ -132,7 +132,7 @@ class EnterpriseDistro(packager.Distro):
return []
if re.search("(redhat|fedora|centos)", self.n):
- return [ "rhel70", "rhel62", "rhel57" ]
+ return [ "rhel80", "rhel70", "rhel62", "rhel57" ]
else:
return super(EnterpriseDistro, self).build_os(arch)
@@ -106,7 +106,7 @@ class EnterpriseDistro(packager.Distro):
raise Exception("BUG: unsupported platform?")
def build_os(self, arch):
- """Return the build os label in the binary package to download ("rhel57", "rhel62", "rhel67" and "rhel70"
+ """Return the build os label in the binary package to download ("rhel57", "rhel62", "rhel67", "rhel70" and "rhel80"
for redhat, the others are delegated to the super class
"""